@@ -1,6 +1,7 @@
 __all__ = ["make_prlc", "make_prlc_rand"]
 
-import grama as gr
+from grama import cp_bounds, cp_copula_independence, cp_function, \
+    cp_bounds, cp_marginals, cp_vec_function, df_make, Model
 from numpy import sqrt
 
 
@@ -14,19 +15,19 @@ L_percent_up = +0.10
 
 def make_prlc():
     md_RLC_det = (
-        gr.Model("RLC Circuit")
-        >> gr.cp_vec_function(
-            fun=lambda df: gr.df_make(sqrt(1 / df.L / df.C)),
+        Model("RLC Circuit")
+        >> cp_vec_function(
+            fun=lambda df: df_make(omega0=sqrt(1 / df.L / df.C)),
             var=["L", "C"],
             out=["omega0"],
         )
-        >> gr.cp_function(
-            fun=lambda df: gr.df_make(Q=df.omega0 * df.R * df.C),
+        >> cp_function(
+            fun=lambda df: df_make(Q=df.omega0 * df.R * df.C),
             name="parallel RLC",
             var=["omega0", "R", "C"],
             out=["Q"]
         )
-        >> gr.cp_bounds(
+        >> cp_bounds(
             R=(1e-3, 1e0),
             L=(1e-9, 1e-3),
             C=(1e-3, 100),
@@ -37,9 +38,9 @@ def make_prlc():
 
 def make_prlc_rand():
     md_RLC_rand = (
-        gr.Model("RLC with component tolerances")
-        >> gr.cp_vec_function(
-            fun=lambda df: gr.df_make(
+        Model("RLC with component tolerances")
+        >> cp_vec_function(
+            fun=lambda df: df_make(
                 Rr=df.R * (1 + df.dR),
                 Lr=df.L * (1 + df.dL),
                 Cr=df.C * (1 + df.dC),
@@ -47,25 +48,25 @@ def make_prlc_rand():
             var=["R", "dR", "L", "dL", "C", "dC"],
             out=["Rr", "Lr", "Cr"],
         )
-        >> gr.cp_vec_function(
-            fun=lambda df: gr.df_make(
+        >> cp_vec_function(
+            fun=lambda df: df_make(
                 omega0=sqrt(1 / df.Lr / df.Cr)
             ),
             var=["Lr", "Cr"],
             out=["omega0"],
         )
-        >> gr.cp_vec_function(
-            fun=lambda df: gr.df_make(Q=df.omega0 * df.Rr * df.Cr),
+        >> cp_vec_function(
+            fun=lambda df: df_make(Q=df.omega0 * df.Rr * df.Cr),
             name="parallel RLC",
             var=["omega0", "Rr", "Cr"],
             out=["Q"]
         )
-        >> gr.cp_bounds(
+        >> cp_bounds(
             R=(1e-3, 1e0),
             L=(1e-9, 1e-3),
             C=(1e-3, 100),
         )
-        >> gr.cp_marginals(
+        >> cp_marginals(
             dR=dict(
                 dist="uniform",
                 loc=R_percent_lo,
@@ -82,7 +83,7 @@ def make_prlc_rand():
                 scale=C_percent_up - C_percent_lo
             ),
         )
-        >> gr.cp_copula_independence()
+        >> cp_copula_independence()
     )
 
     return md_RLC_rand
