@@ -1,6 +1,7 @@
 __all__ = ["make_test", "df_test_input"]
 
-import grama as gr
+from grama import cp_bounds, cp_copula_independence, cp_function, cp_marginals, \
+    Model
 from pandas import DataFrame
 
 
@@ -13,13 +14,13 @@ def fun(x):
     return x1 + x2 + x3
 
 def make_test():
-    md = gr.Model() >> \
-         gr.cp_function(fun=fun, var=3, out=1) >> \
-         gr.cp_bounds(x0=(-1,+1), x1=(-1,+1), x2=(-1,+1)) >> \
-         gr.cp_marginals(
+    md = Model() >> \
+         cp_function(fun=fun, var=3, out=1) >> \
+         cp_bounds(x0=(-1,+1), x1=(-1,+1), x2=(-1,+1)) >> \
+         cp_marginals(
              x0={"dist": "uniform", "loc": -1, "scale": 2},
              x1={"dist": "uniform", "loc": -1, "scale": 2}
          ) >> \
-         gr.cp_copula_independence()
+         cp_copula_independence()
 
     return md
