@@ -57,23 +57,28 @@ from scipy.stats import norm, rankdata
 # -------------------------
 @make_symbolic
 def floor(x):
-    r"""Absolute value
+    r"""Round downwards to nearest integer
     """
     return npfloor(x)
 
 
 @make_symbolic
 def ceil(x):
-    r"""Absolute value
+    r"""Round upwards to nearest integer
     """
     return npceil(x)
 
 
 @make_symbolic
-def round(x):
-    r"""Absolute value
+def round(x, decimals=0):
+    r"""Round value to desired precision
+
+    Args:
+        x (float or iterable of floats): Value(s) to round
+        decimals (int): Number of decimal places for rounding; decimals=0 rounds to integers
+
     """
-    return npround(x)
+    return npround(x, decimals=decimals)
 
 
 @make_symbolic
@@ -281,21 +286,21 @@ def fct_reorder(f, x, fun=median):
     Args:
         f (iterable OR DataFrame column): factor to reorder
         x (iterable OR DataFrame column): variable on which to reorder; specify aggregation method with fun
-        fun (function): aggregation function for reordering
+        fun (function): aggregation function for reordering, default=median
 
     Returns:
         Categorical: Iterable with levels sorted according to x
 
     Examples:
-        >>> import grama as gr
-        >>> from grama.data import df_diamonds
-        >>> X = gr.Intention()
-        >>> (
-        >>>     df_diamonds
-        >>>     >> gr.tf_mutate(cut=gr.fct_reorder(X.cut, X.price, fun=gr.colmax))
-        >>>     >> gr.tf_group_by(X.cut)
-        >>>     >> gr.tf_summarize(max=gr.colmax(X.price), mean=gr.mean(X.price))
-        >>> )
+        import grama as gr
+        from grama.data import df_diamonds
+        DF = gr.Intention()
+        (
+            df_diamonds
+            >> gr.tf_mutate(cut=gr.fct_reorder(DF.cut, DF.price))
+            >> gr.tf_group_by(DF.cut)
+            >> gr.tf_summarize(max=gr.colmax(DF.price), mean=gr.mean(DF.price))
+        )
     """
 
     # Get factor levels
