@@ -5,7 +5,7 @@ import scipy.linalg
 __all__ = ['gauss']
 
 def gauss(N, a = 0, b = 1):
-	r""" Gauss-Legendre quadrature rule 
+	r""" Gauss-Legendre quadrature rule
 
 
 
@@ -32,7 +32,7 @@ def gauss(N, a = 0, b = 1):
 	"""
 	a, b = float(a), float(b)
 
-	beta = 0.5/np.sqrt(1 - ((np.arange(2,2*N, 2, dtype = np.float))**(-2) ))
+	beta = 0.5/np.sqrt(1 - ((np.arange(2,2*N, 2, dtype = float)**(-2) )))
 	T = np.diag(beta, 1) + np.diag(beta, -1)
 
 	# Because eigenvalues come sorted in increasing order, there is no need to sort
@@ -45,4 +45,3 @@ def gauss(N, a = 0, b = 1):
 	w = ((b-a)/2.)*w
 
 	return x, w
-
